Package: saber
Type: Package
Title: Context Engineering for Large Language Model Agents
Version: 0.7.2
Date: 2026-06-24
Authors@R: c(
    person("Troy", "Hernandez", role = c("aut", "cre"),
           email = "troy@cornball.ai",
           comment = c(ORCID = "0009-0005-4248-604X")),
    person("cornball.ai", role = "cph"))
Description: Context-engineering primitives for Artificial Intelligence (AI)
    coding agents working in R. Assembles agent context from memory and
    instruction files ('AGENTS.md', 'CLAUDE.md'), traces function call
    blast radius across projects, generates project briefings, parses
    source into Abstract Syntax Tree (AST) symbol indices, discovers
    dependency graphs, and introspects installed packages.
    Zero dependencies.
License: Apache License (>= 2)
Depends: R (>= 4.4.0)
URL: https://github.com/cornball-ai/saber
BugReports: https://github.com/cornball-ai/saber/issues
Suggests: tinytest
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2026-06-24 19:31:14 UTC; troy
Author: Troy Hernandez [aut, cre] (ORCID:
    <https://orcid.org/0009-0005-4248-604X>),
  cornball.ai [cph]
Maintainer: Troy Hernandez <troy@cornball.ai>
Repository: CRAN
Date/Publication: 2026-06-25 05:20:02 UTC
Built: R 4.4.3; ; 2026-06-25 05:56:49 UTC; unix
